// $Modified: Mon Jun 28 21:18:34 2010 by uwer $
#include "Hathor.h"
#include "HathorPdf.h"
#include <jni.h>
#include <iostream>
#include "LHAPDF/LHAPDF.h"

using namespace std;

/*
 * Java-Interface
 */

static double alphas;
static double pdfup;
static double pdfdown;

extern "C" JNIEXPORT jdouble JNICALL Java_JHathor_xs
(JNIEnv *env, jobject, jint scheme, jint acc, jint collider, jdouble energy,
 jstring pdfname,
 jdouble Cqq, jdouble Cgg,
 jdouble mt, jdouble mur, jdouble muf){

  const char *str;
  str = env->GetStringUTFChars(pdfname, NULL);

  cout << " HATHOR: use " << str << endl;

  Lhapdf pdf(str);
  Hathor xs(pdf);
  
  if ( 0==collider )
    xs.setColliderType(Hathor::PPBAR);
  else
    xs.setColliderType(Hathor::PP);

  xs.setSqrtShad(energy);
  xs.setScheme(scheme);
  xs.setPrecision(acc);
  xs.setCqq(Cqq);
  xs.setCgg(Cgg);

  double res = xs.getXsection(mt,mur,muf);
  alphas = xs.getAlphas(mur);
  if (scheme & Hathor::PDF_SCAN)
    xs.getPdfErr(pdfup,pdfdown);
  else {
    pdfup = 0;
    pdfdown = 0;
  }

  xs.PrintOptions();
  cout << " HATHOR: mt  / mur / muf / alphas / sigma " << endl;
  cout << " HATHOR: " << mt << " " 
       << mur << " " 
       << muf << " " 
       << alphas << " "
       << res << endl;

  env->ReleaseStringUTFChars(pdfname, str);
  return(res);
}

extern "C" JNIEXPORT jdouble JNICALL Java_JHathor_alphas
(JNIEnv *env, jobject){
  return(alphas);
}

extern "C" JNIEXPORT jdouble JNICALL Java_JHathor_pdfup
(JNIEnv *env, jobject){
  return(pdfup);
}

extern "C" JNIEXPORT jdouble JNICALL Java_JHathor_pdfdown
(JNIEnv *env, jobject){
  return(pdfdown);
}
extern "C" JNIEXPORT jstring JNICALL Java_JHathor_pdfpath
(JNIEnv *env, jobject obj){
  string path = LHAPDF::pdfsetsPath();
  jstring comment = env->NewStringUTF(path.c_str());
  return comment;
}

unsigned int scheme_=Hathor::LO|Hathor::NLO|Hathor::NNLO;
int acc_=10000;;
int collider_=1;
double energy_=7000;
double Cqq_=0, Cgg_=0;
char pdfname[255] = "MSTW2008nnlo68cl";

extern "C" double xs(double mt, double mur, double muf){

  cout << " HATHOR: use " << pdfname << endl;

  Lhapdf pdf(pdfname);
  Hathor xs(pdf);
  
  if ( 0==collider_ )
    xs.setColliderType(Hathor::PPBAR);
  else
    xs.setColliderType(Hathor::PP);

  xs.setSqrtShad(energy_);
  xs.setScheme(scheme_);
  xs.setPrecision(acc_);
  xs.setCqq(Cqq_);
  xs.setCgg(Cgg_);

  double res = xs.getXsection(mt,mur,muf);
  alphas = xs.getAlphas(mur);
  if (scheme_ & Hathor::PDF_SCAN)
    xs.getPdfErr(pdfup,pdfdown);
  else {
    pdfup = 0;
    pdfdown = 0;
  }

  xs.PrintOptions();
  cout << " HATHOR: mt  / mur / muf / alphas / sigma " << endl;
  cout << " HATHOR: " << mt << " " 
       << mur << " " 
       << muf << " " 
       << alphas << " "
       << res << endl;

  return(res);
}
