// $Modified: Thu Jun 24 09:56:51 2010 by uwer $
#include "Hathor.h"
#include "HathorPdf.h"
#include <iostream>
#include <fstream>


using namespace std;


void CFMNR(){

  /* 
   * Reproduce fixed order results
   * from Cacciari, Frixione, Mangano, Nason and Ridolfi [JHEP 0809:127,2008]
   */
  double mt=171., mur=171., muf=171.;

  unsigned int scheme = Hathor::LO  | Hathor::NLO;
  Hathor::COLLIDERTYPE collider[]={Hathor::PP, Hathor::PPBAR};
  string pdfname[] = {"cteq65","MRST2006nnlo"};

  ofstream out("CFMNRcheck.log");
  out << "---------------------------------------------------------------"
      << endl
      << "In the following we reproduce the values quoted in" << endl
      << "Cacciari, Frixione, Mangano, Nason, Ridolfi, [JHEP 0809:127,2008]" 
      << endl
      << "The quoted results are: " << endl
      << "alphas(mur), crosssection, uncertainty from numerical integration,"
      << endl 
      << "asymmetric pdf uncertainty" << endl
      << "We use mt=mur=muf=171. GeV" << endl
      << "---------------------------------------------------------------"
      << endl;

  for (int icollider=0; icollider<2; icollider++){
    if ( Hathor::PP == collider[icollider] )
      out 
	<< "---------------------------- LHC ------------------------------"
	<< endl;
    else
      out 
	<< "------------------------- Tevatron ----------------------------"
	<< endl;

    for (int ipdf =0; ipdf<2;ipdf++){
      out << "Using " << pdfname[ipdf] << ":" << endl;
      double val,err,chi,pdfup,pdfdown;      
      Lhapdf pdf(pdfname[ipdf]);
      Hathor XS(pdf);
      
      XS.setColliderType(collider[icollider]);
      XS.setScheme(  scheme );      
      XS.getXsection(mt,mur,muf);
      XS.getResult(0,val,err,chi);

      XS.setScheme(  scheme | Hathor::PDF_SCAN );
      XS.setPrecision(Hathor::LOW);
      XS.getXsection(mt,mur,muf);
      XS.getPdfErr(pdfup,pdfdown);
      
      out << XS.getAlphas(mur) << " " << val << " " << err << " "
	   << pdfup << " " << -pdfdown << " (pdf)"
	   << endl;
    }
  }
}

void scaledep(Hathor & XS, const double m, ofstream &out){
  double muf, mur,val,err,chi;
  for (int imur=-1;imur<2;imur++){
    for (int imuf=-1;imuf<2;imuf++){
      muf = m * pow(2.,imuf);
      mur = m * pow(2.,imur);
      XS.getXsection(m,mur,muf);
      XS.getResult(0,val,err,chi);
      out  << mur <<" " << muf  << " " << XS.getAlphas(mur) << " "
	   << val << " " << err << endl;
    }
  }
}


void LMU09(){
  /*
   * This example reproduces the central curve (NNLO) of the right plot in Fig. 5
   * of Ref. [Langenfeld, Moch, Uwer, PRD 80, 054009 (2009)].
   */
  double val,err,chi;

  Lhapdf lhapdf("MSTW2008nnlo68cl");
  Hathor XS(lhapdf);

  XS.setColliderType(Hathor::PPBAR);
  XS.setScheme(Hathor::LO | Hathor::NLO | Hathor::NNLO | Hathor::MS_MASS );
  //  XS.setPrecision(Hathor::LOW);

  for(double mt = 140; mt < 181.; mt++ ){
    XS.getXsection(mt,mt,mt);
    XS.getResult(0,val,err,chi);
    cout << mt << " " << XS.getAlphas(mt) <<" "<< val << " " << err << endl;
  }
}

int main(){

  double val,err,chi,mt=171;
  Lhapdf lhapdf("MSTW2008nnlo68cl");
  
  Hathor XS(lhapdf);
  XS.setColliderType(Hathor::PPBAR);
  XS.setScheme(Hathor::LO | Hathor::NLO | Hathor::NNLO 
	       | Hathor::MS_MASS | Hathor::PDF_SCAN | Hathor::PDF_SYM_ERR );
  XS.setPrecision(Hathor::LOW);
  XS.getXsection(mt,mt,mt);

  for (int i=0; i< XS.getPdfNumber(); i++) {
    XS.getResult(i,val,err,chi);
    cout << i << " " << val << " " << err << endl;
  }

}
